@@ -156,8 +156,8 @@ class Emitter(object):
         self.column = 0
         self.whitespace = True
         self.indention = True
-        self.compact_seq_seq = True   # dash after dash
-        self.compact_seq_map = True   # key after dash
+        self.compact_seq_seq = True  # dash after dash
+        self.compact_seq_map = True  # key after dash
         # self.compact_ms = False   # dash after key, only when excplicit key with ?
         self.no_newline = None  # type: Optional[bool]  # set if directly after `- `
 
@@ -1024,6 +1024,8 @@ class Emitter(object):
                 if ch in u'?:':  # ToDo
                     if self.serializer.use_version == (1, 1):
                         flow_indicators = True
+                    elif len(scalar) == 1:  # single character
+                        flow_indicators = True
                     if followed_by_whitespace:
                         block_indicators = True
                 if ch == u'-' and followed_by_whitespace:
@@ -1461,9 +1463,12 @@ class Emitter(object):
                         data = data.encode(self.encoding)
                     self.stream.write(data)
                     if ch == u'\a':
-                        self.write_line_break()
-                        self.write_indent()
-                        end += 2  # \a and the space that is inserted on the fold
+                        if end < (len(text) - 1) and not text[end + 2].isspace():
+                            self.write_line_break()
+                            self.write_indent()
+                            end += 2  # \a and the space that is inserted on the fold
+                        else:
+                            raise EmitterError('unexcpected fold indicator \\a before space')
                     if ch is None:
                         self.write_line_break()
                     start = end
@@ -1588,7 +1593,7 @@ class Emitter(object):
             end += 1
 
     def write_comment(self, comment, pre=False):
-        # type: (Any) -> None
+        # type: (Any, bool) -> None
         value = comment.value
         # nprintf('{:02d} {:02d} {!r}'.format(self.column, comment.start_mark.column, value))
         if not pre and value[-1] == '\n':
